##  Step 1: Create an Automation
  1. On the Automations page in the administration area, click New Automation.
  2. Specify general automation parameters: name, description (optional), and owner.
  3. In the When section, specify the trigger for the automation.
  4. In the If section, specify conditions for triggering the automation.
  5. In the Then section, specify actions for the automation.
    1. Click Add Action, then select Send Webhook.
    2. In the Webhook Tag field, enter a webhook tag that serves as the automation identifier.
    3. If needed, add more actions. Actions are initiated sequentially in the order that you specify.
  6. Save the automation.


For detailed information on each configuration parameter, see [Creating an Automation](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758d6af7a441014b829a7547e83bfd4__creating_an_automation).
